@@ -331,16 +331,12 @@ class Window(hildon.StackableWindow):
         #print "drawing buttons"
         vbox_left = gtk.VBox()
         vbox_right = gtk.VBox()
+        lbl_header = gtk.Label("Schedule for date " + self.scheduledate + " (fetched: " + time.strftime("%a, %d %b %Y %H:%M:%S", time.localtime()) + ")")
+        self.vbox.pack_start(lbl_header)
         for index, item in enumerate(self.originalname):
              #If we are closing window then abort
              if (self.exiting): break
-             # vaatame kas on uus teater, kui on siis teeme vahenupu
-             #i = self.theatre.index(self.theatre[index])
-             #if (i == index):
-             #    butt_cinema = hildon.Button(gtk.HILDON_SIZE_AUTO, hildon.BUTTON_ARRANGEMENT_VERTICAL)
-             #    butt_cinema.set_text(self.theatre[index] + " " + self.scheduledate, "")
-             #    self.vbox.pack_start(butt_cinema)
-                 
+                              
              butt_title = hildon.Button(gtk.HILDON_SIZE_AUTO, hildon.BUTTON_ARRANGEMENT_VERTICAL)
              butt_title.set_text(item, "")
              butt_title.connect("clicked", self.btn_movie_clicked, [self.movieid[index], index])
